==> fasc-openapi-java-sdk-5.2.9.2-sources.jar: com/fasc/open/api/bean/common/FieldTextSingleLine.java <==
package com.fasc.open.api.bean.common;

import com.fasc.open.api.bean.base.BaseBean;

/**
 * @author Fadada
 * @date 2021/12/6 9:46:32
 */
public class FieldTextSingleLine extends BaseBean {
    private Boolean required;
    private String defaultValue;
    private String tips;
    private Integer width;
    private Integer height;
    private String fontType;
    private Integer fontSize;
    private String alignment;

    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    public String getDefaultValue() {
        return defaultValue;
    }

    public void setDefaultValue(String defaultValue) {
        this.defaultValue = defaultValue;
    }

    public String getTips() {
        return tips;
    }

    public void setTips(String tips) {
        this.tips = tips;
    }

    public Integer getWidth() {
        return width;
    }

    public void setWidth(Integer width) {
        this.width = width;
    }

    public Integer getHeight() {
        return height;
    }

    public void setHeight(Integer height) {
        this.height = height;
    }

    public String getFontType() {
        return fontType;
    }

    public void setFontType(String fontType) {
        this.fontType = fontType;
    }

    public Integer getFontSize() {
        return fontSize;
    }

    public void setFontSize(Integer fontSize) {
        this.fontSize = fontSize;
    }

    public String getAlignment() {
        return alignment;
    }

    public void setAlignment(String alignment) {
        this.alignment = alignment;
    }
}

==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/bean/common/FieldTextSingleLine.java <==
package com.fasc.open.api.bean.common;

import com.fasc.open.api.bean.base.BaseBean;

/**
 * @author Fadada
 * @date 2021/12/6 9:46:32
 */
public class FieldTextSingleLine extends BaseBean {
    private Boolean required;
    private String defaultValue;
    private String tips;
    private Integer width;
    private Integer height;
    private String fontType;
    private Integer fontSize;
    private String alignment;
    private String autofillInfo;
    private Boolean autofill;

    public String getAutofillInfo() {
        return autofillInfo;
    }

    public void setAutofillInfo(String autofillInfo) {
        this.autofillInfo = autofillInfo;
    }

    public Boolean getAutofill() {
        return autofill;
    }

    public void setAutofill(Boolean autofill) {
        this.autofill = autofill;
    }

    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    public String getDefaultValue() {
        return defaultValue;
    }

    public void setDefaultValue(String defaultValue) {
        this.defaultValue = defaultValue;
    }

    public String getTips() {
        return tips;
    }

    public void setTips(String tips) {
        this.tips = tips;
    }

    public Integer getWidth() {
        return width;
    }

    public void setWidth(Integer width) {
        this.width = width;
    }

    public Integer getHeight() {
        return height;
    }

    public void setHeight(Integer height) {
        this.height = height;
    }

    public String getFontType() {
        return fontType;
    }

    public void setFontType(String fontType) {
        this.fontType = fontType;
    }

    public Integer getFontSize() {
        return fontSize;
    }

    public void setFontSize(Integer fontSize) {
        this.fontSize = fontSize;
    }

    public String getAlignment() {
        return alignment;
    }

    public void setAlignment(String alignment) {
        this.alignment = alignment;
    }
}
